#
# spec file for package tecnoballz
#
# Copyright (c) 2023 SUSE LLC
# Copyright Vincent Petry <PVince81@yahoo.fr>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tecnoballz
Version:        0.93.1
Release:        5.3
Summary:        A brick breaking game
License:        GPL-3.0-only
Group:          Amusements/Games/Action/Breakout
URL:            http://linux.tlk.fr/games/TecnoballZ/
Source:         http://linux.tlk.fr/games/TecnoballZ/download/%{name}-%{version}.tgz
Source1:        %{name}.desktop
Source2:        %{name}.png
# PATCH-FIX-OPENSUSE disable-Werror.patch
Patch1:         disable-Werror.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  tinyxml-devel
BuildRequires:  pkgconfig(SDL_image)
BuildRequires:  pkgconfig(SDL_mixer)
BuildRequires:  pkgconfig(libmikmod)
BuildRequires:  pkgconfig(sdl)
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif

%description
A brick breaker with 50 levels of game and 11 special levels,
distributed on the 2 modes of game to give the player a sophisticated system
of attack weapons with an enormous firepower that can be built by
gaining bonuses.  Numerous decors, music and sounds complete this
game. This game was ported from the Commodore Amiga.

%prep
%autosetup -p1

# Fix games path to %%{_bindir} instead of /usr/games
find -name Makefile.am -exec sed -i -e "s|^gamesdir =.*$|gamesdir = %{_bindir}|g" \{\} +

sed -i -e "s|^CXXFLAGS=\"\(.*\)\"|CXXFLAGS=\"\1 %{optflags}\"|" configure.ac

%build
autoreconf -fi
%configure
%make_build

%install
%make_install
install -Dm 0644 man/%{name}.fr.6 %{buildroot}%{_mandir}/fr/man6/%{name}.6
install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/%{name}.png

%if 0%{?suse_version}
%suse_update_desktop_file %{name}
%endif

%fdupes -s %{buildroot}%{_prefix}

%files
%license COPYING
%doc AUTHORS CHANGES NEWS README
%attr(0755,root,root) %{_bindir}/%{name}
%{_mandir}/fr/man6/%{name}.6%{?ext_man}
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%dir %{_localstatedir}/games/
%attr(0775,games,games) %dir %{_localstatedir}/games/%{name}/
%attr(0664,games,games)%{_localstatedir}/games/%{name}/%{name}.hi

%changelog
* Thu May  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add disable-Werror.patch: disable Werror, patch lifted from
  debian. Yes this is a bit of a big hammer, but it works.
- Following the above, drop
  0001-Workaround-compilation-warnings-with-gccs-8.0.patch
- Use autosetup and make_build macros.
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description.
- Use regular install, not install-strip.
* Sat Jul 27 2019 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-Workaround-compilation-warnings-with-gccs-8.0.patch
- Run spec-cleaner
- Use pkg-config style BuildRequires
* Fri Apr  7 2017 meissner@suse.com
- own /var/games as filesystem no longer owns it
* Tue Oct  7 2014 nemysis@gmx.ch
- Change tecnoballz.desktop, forgotten in previous commit
* Tue Oct  7 2014 nemysis@gmx.ch
- Update to 0.93.1, announce message:
  TecnoballZ 0.93.1
  add patch from Musuruan
  - make will fail because there is no rule to make supervisor.c
  - make install will fail because it cannot find tecnoballz.hi since it's
  in the parent directory
  TecnoballZ 0.93
  Fix warnings with GCC 4.3 and 4.7.2
  Fix Makefile
  Fix bugs (Debian #510492) sprites (balls and and gems) are drawn on the right panel
  Fix a segfault caused by a calculation of coordinates of sprites unsigned.
  Fix paddle movment restriction when, or after, control reverse penality
  (bug fixed by Celelibi Debian bug #510603)
  Updates the code that loads the configuration file.
  Migrating Berlios CVS source repository to Google Code Project hosting Subversion
  Added support for XDG_CONFIG_HOME
  Fix bug Collision check not accruate enough for fast balls.
  (bug fixed by Celelibi Debian bug #510770)
  Use tinyxml system library (Ansgar Burchardt from Debian)
- Change Source0 to use Web URL
- Remove obsolete patches, changed by upstream
- Add BuildRequires for fdupes and tinyxml-devel
- Change description
- Add %%{name}.fr.6
* Sun May 27 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Mon Jan  4 2010 PVince81@yahoo.fr
- Changed SDL dependencies to SDL instead of libSDL
* Wed Oct  7 2009 PVince81@yahoo.fr
- Initial package
